==> nomadic_2025_01_17.zip: nomadic/storage/framework/views/653c4d10e605b0189db41c607bc38ea68bcf0a6a.php <==
<div class="container" data-aos="fade-up">
  <h1 class="txtwhite mb-4">Upcoming events</h1>
  <div class="row">
  <?php if($events->count() > 0): ?>
    <?php $__currentLoopData = $events; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $event): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
    <div class="col-md-3 mb-4">
      <div class="position-relative">
        <div class="imgbox">
          <img src="img/upcomingevent/upcoevnt1.jpg" class="imgfluidlogged">
        </div>  
      </div>
      <div class="clearfix"></div>
      <div class="mt-2 mb-2 txtwhite"><?php echo e(date('l, d M',strtotime($event->event_date))); ?> AT <?php echo e(date('h:i A',strtotime($event->event_time))); ?></div>
      <div class="clearfix"></div>
      <h4 class="mb-2 txtwhite"><?php echo e(Str::limit(ucfirst($event->event_title),25)); ?></h4>
      <div class="clearfix"></div>
      <?php if($event->event_type=='online'): ?>
      <div class="mb-2 txtwhite"><?php echo e($event->event_type); ?></div>
      <?php endif; ?>
      <?php if($event->event_type=='location' && $event->address!=''): ?>
      <div class="mb-2 txtwhite"><?php echo e($event->address); ?></div>
      <?php endif; ?>
      <div class="clearfix"></div>
      <div class="mb-4 txtwhite font13px"><?php echo e($event->interested_count); ?> interested <?php echo e($event->going_count); ?> going</div>
      <div class="clearfix"></div>
      <div class="d-inline position-relative">
        <button type="button" class="btn btnwhite" <?php if(Auth::guest()): ?> disabled <?php elseif(isset($event->interested[0]->user_id)): ?> disabled <?php else: ?> onclick="event_action(this,<?php echo e($event->event_id); ?>,'interested')" <?php endif; ?>>Interested</button>
        <button type="button" class="btn btnwhite" <?php if(Auth::guest()): ?> disabled <?php elseif(isset($event->going[0]->user_id)): ?> disabled <?php else: ?> onclick="event_action(this,<?php echo e($event->event_id); ?>,'going')" <?php endif; ?>>Going</button>
        <button type="button" class="btn2 btnwhite d-inline minwidth position-relative" onclick="share(<?php echo e($event->event_id); ?>)">
          <i class="bi bi-share mlmr"></i>
        </button>
      </div>
    </div>
    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
  <?php endif; ?>
  </div>    
</div><?php /**PATH /var/www/html/nomadic/resources/views/frontend/event/upcoming-events.blade.php ENDPATH**/ ?>

==> nomadic_2025_07_19.zip: nomadic/storage/framework/views/653c4d10e605b0189db41c607bc38ea68bcf0a6a.php <==
<div class="container" data-aos="fade-up">
  <h1 class="txtwhite mb-4">Upcoming events</h1>
  <div class="row">
  <?php if($events->count() > 0): ?>
    <?php $__currentLoopData = $events; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $event): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
    <div class="col-md-3 mb-4">
      <div class="position-relative">
        <div class="imgbox">
          <img src="img/upcomingevent/upcoevnt1.jpg" class="imgfluidlogged">
        </div>  
      </div>
      <div class="clearfix"></div>
      <div class="mt-2 mb-2 txtwhite"><?php echo e(date('l, d M',strtotime($event->event_date))); ?> AT <?php echo e(date('h:i A',strtotime($event->event_time))); ?></div>
      <div class="clearfix"></div>
      <h4 class="mb-2 txtwhite"><?php echo e(Str::limit(ucfirst($event->event_title),25)); ?></h4>
      <div class="clearfix"></div>
      <?php if($event->event_type=='online'): ?>
      <div class="mb-2 txtwhite"><?php echo e($event->event_type); ?></div>
      <?php endif; ?>
      <?php if($event->event_type=='location' && $event->address!=''): ?>
      <div class="mb-2 txtwhite"><?php echo e($event->address); ?></div>
      <?php endif; ?>
      <div class="clearfix"></div>
      <div class="mb-4 txtwhite font13px"><?php echo e($event->interested_count); ?> interested <?php echo e($event->going_count); ?> going</div>
      <div class="clearfix"></div>
      <div class="d-inline position-relative">
        <button type="button" class="btn btnwhite mb-2" <?php if(Auth::guest()): ?> disabled <?php elseif(isset($event->interested[0]->user_id)): ?> disabled <?php else: ?> onclick="event_action(this,<?php echo e($event->event_id); ?>,'interested')" <?php endif; ?>>Interested <i class="bi bi-hand-thumbs-up"></i></button>
        <?php if($event->public_private=='public'): ?>
        <button type="button" class="btn btnwhite goingevent mb-2" data-event="<?php echo e($event->event_id); ?>" <?php if(Auth::guest()): ?> disabled <?php elseif(isset($event->going[0]->user_id)): ?> disabled <?php endif; ?>><span><?php if(!empty($event->ticket_price)): ?> <?php echo e($event->ticket_price); ?> Points <?php endif; ?></span> Going <i class="bi bi-arrow-right"></i></button>
        <?php endif; ?>
        <button type="button" class="btn2 btnwhite d-inline minwidth position-relative mb-2" onclick="share(<?php echo e($event->event_id); ?>)">
          <i class="bi bi-share mlmr"></i>
        </button>
      </div>
    </div>
    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
  <?php endif; ?>
  </div>    
</div><?php /**PATH /var/www/html/nomadic/resources/views/frontend/event/upcoming-events.blade.php ENDPATH**/ ?>
